@@ -8,15 +8,15 @@
 
 
 
-.emmeans_prediction_data <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, model_info, ...) {
+.emmeans_prediction_data <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, model_info, interval = NULL, model_data = NULL, ...) {
   if (inherits(model, "MCMCglmm")) {
-    prediction_data <- .ggemmeans_predict_MCMCglmm(model, data_grid, cleaned_terms, ci.lvl, pmode, type, ...)
+    prediction_data <- .ggemmeans_predict_MCMCglmm(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = interval, model_data = model_data, ...)
   } else if (model_info$is_ordinal | model_info$is_multinomial | model_info$is_categorical) {
-    prediction_data <- .ggemmeans_predict_ordinal(model, data_grid, cleaned_terms, ci.lvl, type, ...)
+    prediction_data <- .ggemmeans_predict_ordinal(model, data_grid, cleaned_terms, ci.lvl, type, interval = interval, model_data = model_data, ...)
   } else if (inherits(model, c("gls", "lme"))) {
-    prediction_data <- .ggemmeans_predict_nlme(model, data_grid, cleaned_terms, ci.lvl, type, ...)
+    prediction_data <- .ggemmeans_predict_nlme(model, data_grid, cleaned_terms, ci.lvl, type, interval = interval, model_data = model_data, ...)
   } else {
-    prediction_data <- .ggemmeans_predict_generic(model, data_grid, cleaned_terms, ci.lvl, pmode, type, ...)
+    prediction_data <- .ggemmeans_predict_generic(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = interval, model_data = model_data, ...)
   }
 }
 
@@ -27,10 +27,9 @@
 
 
 
-#' @importFrom stats formula
 .ggemmeans_MixMod <- function(model, data_grid, cleaned_terms, ...) {
   if (!requireNamespace("emmeans")) {
-    stop("Package `emmeans` required to compute marginal effects for MixMod-models.", call. = FALSE)
+    stop("Package `emmeans` required to compute estimated marginal means for MixMod-models.", call. = FALSE)
   }
 
   x1 <- as.data.frame(suppressWarnings(emmeans::emmeans(
@@ -58,7 +57,7 @@
 
 .ggemmeans_glmmTMB <- function(model, data_grid, cleaned_terms, ...) {
   if (!requireNamespace("emmeans")) {
-    stop("Package `emmeans` required to compute marginal effects for glmmTMB-models.", call. = FALSE)
+    stop("Package `emmeans` required to estimated marginal means effects for glmmTMB-models.", call. = FALSE)
   }
 
   x1 <- as.data.frame(suppressWarnings(emmeans::emmeans(
@@ -85,7 +84,7 @@
 
 
 
-.ggemmeans_predict_ordinal <- function(model, data_grid, cleaned_terms, ci.lvl, type, ...) {
+.ggemmeans_predict_ordinal <- function(model, data_grid, cleaned_terms, ci.lvl, type, interval = NULL, model_data = NULL, ...) {
   tmp <- emmeans::emmeans(
     model,
     specs = c(insight::find_response(model, combine = FALSE), cleaned_terms),
@@ -94,7 +93,7 @@
     ...
   )
 
-  .ggemmeans_add_confint(model, tmp, ci.lvl, type, pmode = "prob")
+  .ggemmeans_add_confint(model, tmp, ci.lvl, type, pmode = "prob", interval)
 }
 
 
@@ -102,7 +101,7 @@
 
 
 
-.ggemmeans_predict_MCMCglmm <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, ...) {
+.ggemmeans_predict_MCMCglmm <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = NULL, model_data = NULL, ...) {
   tmp <- emmeans::emmeans(
     model,
     specs = cleaned_terms,
@@ -112,14 +111,14 @@
     ...
   )
 
-  .ggemmeans_add_confint(model, tmp, ci.lvl, type, pmode)
+  .ggemmeans_add_confint(model, tmp, ci.lvl, type, pmode, interval)
 }
 
 
 
 
 
-.ggemmeans_predict_generic <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, ...) {
+.ggemmeans_predict_generic <- function(model, data_grid, cleaned_terms, ci.lvl, pmode, type, interval = NULL, model_data = NULL, ...) {
 
   tmp <- tryCatch(
     {
@@ -134,15 +133,36 @@
       )
     },
     error = function(e) {
-      insight::print_color("Can't compute marginal effects, 'emmeans::emmeans()' returned an error.\n\n", "red")
-      cat(sprintf("Reason: %s\n", e$message))
-      cat("You may try 'ggpredict()' or 'ggeffect()'.\n\n")
       NULL
     }
   )
 
+  if (is.null(tmp)) {
+    tmp <- tryCatch(
+      {
+        suppressWarnings(
+          emmeans::emmeans(
+            model,
+            specs = cleaned_terms,
+            at = data_grid,
+            mode = pmode,
+            data = insight::get_data(model),
+            ...
+          )
+        )
+      },
+      error = function(e) {
+        insight::print_color("Can't compute estimated marginal means, 'emmeans::emmeans()' returned an error.\n\n", "red")
+        cat(sprintf("Reason: %s\n", e$message))
+        cat("You may try 'ggpredict()' or 'ggeffect()'.\n\n")
+        NULL
+      }
+    )
+  }
+
+
   if (!is.null(tmp))
-    .ggemmeans_add_confint(model, tmp, ci.lvl, type, pmode)
+    .ggemmeans_add_confint(model, tmp, ci.lvl, type, pmode, interval)
   else
     NULL
 }
@@ -151,7 +171,7 @@
 
 
 
-.ggemmeans_predict_nlme <- function(model, data_grid, cleaned_terms, ci.lvl, type, ...) {
+.ggemmeans_predict_nlme <- function(model, data_grid, cleaned_terms, ci.lvl, type, interval = NULL, model_data = NULL, ...) {
 
   tmp <- tryCatch(
     {
@@ -165,7 +185,7 @@
       )
     },
     error = function(e) {
-      insight::print_color("Can't compute marginal effects, 'emmeans::emmeans()' returned an error.\n\n", "red")
+      insight::print_color("Can't compute estimated marginal means, 'emmeans::emmeans()' returned an error.\n\n", "red")
       cat(sprintf("Reason: %s\n", e$message))
       cat("You may try 'ggpredict()' or 'ggeffect()'.\n\n")
       NULL
