@@ -1,8 +1,4 @@
 #' @rdname ggpredict
-#'
-#' @importFrom stats na.omit
-#' @importFrom sjlabelled as_numeric
-#' @importFrom insight find_predictors link_inverse print_color
 #' @export
 ggeffect <- function(model, terms, ci.lvl = .95, ...) {
 
@@ -18,6 +14,11 @@ ggeffect <- function(model, terms, ci.lvl = .95, ...) {
     terms <- all.vars(terms)
   }
 
+  # tidymodels?
+  if (inherits(model, "model_fit")) {
+    model <- model$fit
+  }
+
   if (inherits(model, "list")  && !inherits(model, c("bamlss", "maxLik"))) {
     res <- lapply(model, function(.x) ggeffect_helper(.x, terms, ci.lvl, ...))
   } else {
@@ -216,6 +217,7 @@ ggeffect_helper <- function(model, terms, ci.lvl, ...) {
 
   # get axis titles and labels
   all.labels <- .get_axis_titles_and_labels(
+    model,
     original_model_frame,
     terms,
     .get_model_function(model),
