@@ -23,6 +23,12 @@
   # make sure we don't have arrays as variables
   model_frame[] <- lapply(model_frame, function(i) if (is.array(i)) as.data.frame(i) else i)
 
+  # we may have factors converted on the fly in the formula, which are,
+  # however, numeric in the original data. We need to coerce to factor here,
+  # and back to numeric later...
+  on_the_fly_factors <- attributes(model_frame)$factors
+  model_frame[] <- lapply(model_frame, function(i) if (isTRUE(attributes(i)$factor)) as.factor(i) else i)
+
   # check for logical variables, might not work
   if (any(sapply(model_frame, is.logical))) {
     stop("Variables of type 'logical' do not work, please coerce to factor and fit the model again.", call. = FALSE)
@@ -49,7 +55,7 @@
   all_terms <- .clean_terms(terms)
 
 
-  # check if user has any predictors with log-transformatio inside
+  # check if user has any predictors with log-transformation inside
   # model formula, but *not* used back-transformation "exp". Tell user
   # so she's aware of the problem
 
@@ -135,6 +141,30 @@
   focal_terms <- c(focal_terms, constant_levels)
 
 
+  # check for monotonic terms and valid values. In case 'mo()' is used,
+  # and predictor is numeric, prettyfied values in the data grid are based
+  # on the range of the numeric variable, although only those values are allowed
+  # in the data grid that actually appear in the data
+
+  if (inherits(model, "brmsfit")) {
+    model_terms <- insight::find_terms(model, flatten = TRUE)
+    monotonics <- grepl("mo\\((.*)\\)", model_terms)
+    if (any(monotonics)) {
+      mo_terms <- gsub("mo\\((.*)\\)", "\\1", model_terms[monotonics])
+      invalid_levels <- unlist(lapply(mo_terms, function(mt) {
+        if (mt %in% names(focal_terms) && mt %in% colnames(model_frame)) {
+          !all(model_frame[[mt]] %in% focal_terms[[mt]])
+        } else {
+          FALSE
+        }
+      }))
+      if (any(invalid_levels)) {
+        stop(insight::format_message(sprintf("Variable(s) '%s' are used as monotonic effects, however, only values that are also present in the data are allowed for predictions. Consider converting variables used in 'mo()' into (ordered) factors before fitting the model.", paste0(mo_terms, collapse = ", "))), call. = FALSE)
+      }
+    }
+  }
+
+
   ## TODO check for other panelr models
 
   # get names of all predictor variable
@@ -433,6 +463,17 @@
     }
   }
 
+  # for numeric variables, that are coerced to factors on-the-fly via formula,
+  # convert back to numeric, so types match with original data. some models,
+  # like brms, would fail for type mismatch
+  if (!is.null(on_the_fly_factors)) {
+    on_the_fly_factors <- on_the_fly_factors[on_the_fly_factors %in% colnames(datlist)]
+    if (length(on_the_fly_factors)) {
+      for (i in on_the_fly_factors) {
+        datlist[[i]] <- .factor_to_numeric(datlist[[i]])
+      }
+    }
+  }
 
   # save constant values as attribute
   attr(datlist, "constant.values") <- constant_values
