@@ -1,8 +1,6 @@
 # return levels, as list
 # c("age", "edu [1,3]", "sex [2]") would return a list:
 # $edu [1] 1 3; $sex [1] 2
-#' @importFrom stats setNames sd
-#' @importFrom sjlabelled as_numeric
 .get_representative_values <- function(x, model_frame = NULL) {
   # get variable with suffix
   terms_with_suffix <- which(as.vector(regexpr(pattern = "([^\\]]*)\\]", text = x, perl = TRUE)) != -1)
@@ -67,10 +65,7 @@
 
       if (is.factor(x)) {
         if (.is_numeric_factor(x)) {
-          x <- sjlabelled::as_numeric(
-            droplevels(x),
-            keep.labels = FALSE
-          )
+          x <- .factor_to_numeric(droplevels(x))
         } else {
           x <- as.character(x)
         }
@@ -127,7 +122,7 @@
   # check if levels were numeric or not...
   suppressWarnings(
     if (!anyNA(unlist(lapply(at_levels, as.numeric)))) {
-      at_levels <- lapply(at_levels, as.numeric)
+      at_levels <- lapply(at_levels, function(i) stats::setNames(as.numeric(i), names(i)))
     }
   )
 
