@@ -6,8 +6,6 @@ if (suppressWarnings(
   require("sjstats") &&
   require("sjmisc")
 )) {
-  context("ggeffects, svyglm.nb")
-
   # svyglm.nb -----
 
   data(nhanes_sample)
@@ -25,12 +23,7 @@ if (suppressWarnings(
   fit <- svyglm.nb(total ~ RIAGENDR + age + RIDRETH1, des)
 
   test_that("ggpredict, svyglm.nb", {
-    ggpredict(fit, "age")
-    ggpredict(fit, c("age", "RIAGENDR"))
-  })
-
-  test_that("ggaverage, svyglm.nb", {
-    ggaverage(fit, "age")
-    ggaverage(fit, c("age", "RIAGENDR"))
+    expect_s3_class(ggpredict(fit, "age"), "data.frame")
+    expect_s3_class(ggpredict(fit, c("age", "RIAGENDR")), "data.frame")
   })
 }
